#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stack
version:              2.9.3.1
visibility:           public
id:                   stack-2.9.3.1-Fbrqd2MmPTfD6DfD8qK1RD
key:                  stack-2.9.3.1-Fbrqd2MmPTfD6DfD8qK1RD
license:              BSD-3-Clause
maintainer:           manny@fpcomplete.com
author:               Commercial Haskell SIG
homepage:             http://haskellstack.org
synopsis:             The Haskell Tool Stack
description:
    Please see the documentation at <https://docs.haskellstack.org>
    for usage information.

    If building a '\''stack'\'' executable for distribution, please download the
    source code from <https://github.com/commercialhaskell/stack/releases>
    and build it using Stack itself in order to ensure identical behaviour
    to official binaries.  This package on Hackage is provided for convenience
    and bootstrapping purposes.

    Note that the API for the library is not currently stable, and may
    change significantly, even between minor releases. It is
    currently only intended for use by the executable.

category:             Development
abi:                  0d04b0fab7fb4947777612e2ee6cbc0b
exposed:              True
exposed-modules:
    Control.Concurrent.Execute Data.Attoparsec.Args
    Data.Attoparsec.Combinators Data.Attoparsec.Interpreter
    Data.Monoid.Map Network.HTTP.StackClient Options.Applicative.Args
    Options.Applicative.Builder.Extra Options.Applicative.Complicated
    Path.CheckInstall Path.Extra Path.Find Paths_stack Stack.Build
    Stack.Build.Cache Stack.Build.ConstructPlan Stack.Build.Execute
    Stack.Build.Haddock Stack.Build.Installed Stack.Build.Source
    Stack.Build.Target Stack.BuildPlan Stack.Clean Stack.Config
    Stack.Config.Build Stack.Config.Docker Stack.Config.Nix
    Stack.ConfigCmd Stack.Constants Stack.Constants.Config
    Stack.Coverage Stack.DefaultColorWhen Stack.Docker Stack.Dot
    Stack.FileWatch Stack.GhcPkg Stack.Ghci Stack.Ghci.Script
    Stack.Hoogle Stack.IDE Stack.Init Stack.List Stack.Lock Stack.Ls
    Stack.New Stack.Nix Stack.Options.BenchParser
    Stack.Options.BuildMonoidParser Stack.Options.BuildParser
    Stack.Options.CleanParser Stack.Options.Completion
    Stack.Options.ConfigParser Stack.Options.DockerParser
    Stack.Options.DotParser Stack.Options.ExecParser
    Stack.Options.GhcBuildParser Stack.Options.GhcVariantParser
    Stack.Options.GhciParser Stack.Options.GlobalParser
    Stack.Options.HaddockParser Stack.Options.HpcReportParser
    Stack.Options.LogLevelParser Stack.Options.NewParser
    Stack.Options.NixParser Stack.Options.PackageParser
    Stack.Options.ResolverParser Stack.Options.SDistParser
    Stack.Options.ScriptParser Stack.Options.TestParser
    Stack.Options.UploadParser Stack.Options.Utils Stack.Package
    Stack.PackageDump Stack.Path Stack.Prelude Stack.Runners
    Stack.SDist Stack.Script Stack.Setup Stack.Setup.Installed
    Stack.SetupCmd Stack.SourceMap Stack.Storage.Project
    Stack.Storage.User Stack.Storage.Util Stack.Types.Build
    Stack.Types.Compiler Stack.Types.CompilerBuild Stack.Types.Config
    Stack.Types.Config.Build Stack.Types.Docker Stack.Types.GhcPkgId
    Stack.Types.NamedComponent Stack.Types.Nix Stack.Types.Package
    Stack.Types.PackageName Stack.Types.Resolver Stack.Types.SourceMap
    Stack.Types.TemplateName Stack.Types.Version Stack.Unpack
    Stack.Upgrade Stack.Upload System.Info.ShortPathName
    System.Permissions System.Process.Pager System.Terminal

hidden-modules:
    Path.Extended Stack.ComponentFile Stack.PackageFile
    Stack.Types.Cache Stack.Types.Dependency Stack.Types.PackageFile
    Stack.Types.Storage System.Uname

import-dirs:          /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/stack
hs-libraries:         HSstack-2.9.3.1-Fbrqd2MmPTfD6DfD8qK1RD
depends:
    Cabal-3.10.3.0 aeson-2.2.2.0-3pjCpj5XtaHAHmzSwnt06z
    annotated-wl-pprint-0.7.0-GFWp72SduKx5Zv0YaM2sPQ
    ansi-terminal-1.1-FMAjddYCnoo35p0Ajg6Jk8 array-0.5.6.0
    async-2.2.6-ClOW2oFWjQTDZxVKjsrmlu
    attoparsec-0.14.4-8xTfRBafHfnLSxW1Zd3VTX base-4.18.2.1
    base64-bytestring-1.2.1.0-LZzfJtlIG52AkUlWG0qoMe
    bytestring-0.11.5.3 casa-client-0.0.4-LQ6o0SCwrZ8B41jQEhP4PY
    casa-types-0.0.3-JQIMMoYH1zJFarzqHBR5gP
    colour-2.3.7-52DaKKnDbdRf7CUEo3dC5
    conduit-1.3.6.1-A5CFvWaedHyBbFpBELr7ED
    conduit-extra-1.3.8-4LNkvIzwsWe54JJPbCmwjx containers-0.6.7
    crypton-1.0.5-ISaCEA7WOGuAiZSS5ibrwY
    crypton-conduit-0.2.3-Lwy8eBbRNhXGJcx3neq3I6 deepseq-1.4.8.1
    directory-1.3.8.5 echo-0.1.4-BCPf0iNIcqQJp7PonIPBEA
    exceptions-0.10.7 extra-1.7.16-aWEq6cZZ289lIc6yxljo5
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz
    filelock-0.1.1.9-BvyQes2ggWCE7hM1ER8bFf filepath-1.4.300.1
    fsnotify-0.4.4.0-13psT0N2K67ArFRlT2nWVV
    generic-deriving-1.14.7-CoIgkO7P5bpIFNJHNdJL3h
    hackage-security-0.6.3.2-EVj45HdfFMMBVWsIKM3EkW
    hashable-1.4.7.0-KYRxVQLzygQHnYjqLKyJPN
    hi-file-parser-0.1.8.0-BtqCHxRisf09AAcUxFZRI
    hpack-0.38.0-7iD5bJzwjlCCmKvDfEuXUm hpc-0.6.2.0
    http-client-0.7.19-JFk9tUfcyF3FnWNRzLmEjW
    http-client-tls-0.3.6.4-Dj2m0zumhuN7HSttI52C5a
    http-conduit-2.3.9.1-2GTRnba790eGqDwPWAtOWK
    http-download-0.2.1.0-GhGOWZK8oY4EAbYVU9BsLB
    http-types-0.12.4-FjxwRmZWhoR3wzry1r4T66
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    mintty-0.1.4-CFeOovjDLzzJb68ZeM2nF
    mono-traversable-1.0.21.0-AJMuHndY0TfBj9ZshA2GC mtl-2.3.1
    mustache-2.4.3.1-JujPPKSiLywFAAPHSm1bK4
    neat-interpolation-0.5.1.4-1AtQWmXcHzy8ck1rIVLXte
    network-uri-2.6.4.2-2pvBC2E3r3ZG7itzgqfKfv
    open-browser-0.2.1.1-LxNiN4VEneo8bxQiPfYDai
    optparse-applicative-0.18.1.0-5QX38E1JQlq4e4oHsAaFH0
    pantry-0.8.3-8YVoJNPo3ip6bRJDK4KLAU
    path-0.9.6-IfAcb5AzeDo82810ZwKtAZ
    path-io-1.8.2-F3tqdr90tE11PHboJAmd3i
    persistent-2.14.6.1-GEU3f5Qg3bVH7PMKZ9qrSb
    persistent-sqlite-2.13.3.0-A3wWPqLmU3FJz5uMBQ3PU8 pretty-1.1.3.6
    primitive-0.9.1.0-MBLhlhjxKECZedf7vLmE9 process-1.6.19.0
    project-template-0.2.1.0-CXryfXf58kZ9cS0RMUbg0r
    random-1.2.1.3-FxwYxgjgoojJKMc450MWAC
    retry-0.9.3.1-E73ToNh7kRG48IWBPzkfI0
    rio-0.1.25.0-K9VJ4ds2ZZw4Ona2QDMlIX
    rio-prettyprint-0.1.9.0-8c0Ewk0fQZXIb6LlN7K5tN
    split-0.2.5-3KQHz3VjCt4O3lCLzOFzl stm-2.5.1.0
    streaming-commons-0.2.3.1-MBAvoCiutqJfVNhb5nEzw
    tar-0.6.0.0-CS1qXsaZUlT4fTNTxcamJK template-haskell-2.20.0.0
    temporary-1.3-6LHFZ2D4FfEKQZFjyV7a7h text-2.0.2
    text-metrics-0.3.3-3D92e8KSf4X2vbxAICnJ5c
    th-reify-many-0.1.10-BCpZgQnngXzKkBNlLvjD0M time-1.12.2
    tls-2.0.6-KODXqScNPtDErnnkyIokYw transformers-0.6.1.0
    typed-process-0.2.13.0-3fEd93V0TXmE2z8JtzQYbJ
    unicode-transforms-0.4.0.1-JXmhVs6fMjdHnJyI8DKdnr unix-2.8.4.0
    unix-compat-0.7.4.1-8Nyb3Roak9p6hLEN8WA8dO
    unliftio-0.2.25.1-95hsWJFispi2AzgK8xFJw
    unordered-containers-0.2.21-5Z67IC6H036CG8YRUzTmvt
    vector-0.13.2.0-9mJIQr0XJi1KVzSJMcMTkU
    yaml-0.11.11.2-LUugXbkeJApKC0qW2gmxvA
    zip-archive-0.4.3.2-GONN1ApDpcNFsRXWAlSFJH
    zlib-0.7.1.0-HgVwWopIY16LHV8ByRCkHf

haddock-interfaces:   /usr/share/doc/stack/html/stack.haddock
haddock-html:         /usr/share/doc/stack/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

